@@ -531,7 +531,7 @@ class Irc(BotBase):
         if not channel or not who: return
         self._raw('MODE %s -o %s' % (channel, who))
 
-    def quit(self, reason='http://fbfbot.googlecode.com & http:///docs/fbfbot'):
+    def quit(self, reason='http://github.com/feedbackflow/fbfbot & http:///docs/fbfbot'):
         """ send quit message. """
         logging.warn('sending quit - %s (%s)' % (reason, self.cfg.name))
         self._raw('QUIT :%s' % reason)
